pub struct StreamConsumer<C = DefaultConsumerContext, R = TokioRuntime>where
C: ConsumerContext,{ /* private fields */ }Expand description
A high-level consumer with a Stream interface.
This consumer doesn’t need to be polled explicitly. Extracting an item from
the stream returned by the stream will
implicitly poll the underlying Kafka consumer.
If you activate the consumer group protocol by calling
subscribe, the stream consumer will integrate with
librdkafka’s liveness detection as described in KIP-62. You must be sure
that you attempt to extract a message from the stream consumer at least
every max.poll.interval.ms milliseconds, or librdkafka will assume that
the processing thread is wedged and leave the consumer groups.
Implementations
Sourceimpl<C, R> StreamConsumer<C, R>where
C: ConsumerContext + 'static,
impl<C, R> StreamConsumer<C, R>where
C: ConsumerContext + 'static,
Sourcepub fn stream(&self) -> MessageStream<'_>
pub fn stream(&self) -> MessageStream<'_>
Constructs a stream that yields messages from this consumer.
It is legal to have multiple live message streams for the same consumer, and to move those message streams across threads. Note, however, that the message streams share the same underlying state. A message received by the consumer will be delivered to only one of the live message streams. If you seek the underlying consumer, all message streams created from the consumer will begin to draw messages from the new position of the consumer.
If you want multiple independent views of a Kafka topic, create multiple consumers, not multiple message streams.
Sourcepub fn start(&self) -> MessageStream<'_>
👎Deprecated: use the more clearly named “StreamConsumer::stream” method instead
pub fn start(&self) -> MessageStream<'_>
Constructs a stream that yields messages from this consumer.
Sourcepub async fn recv(&self) -> Result<BorrowedMessage<'_>, KafkaError>
pub async fn recv(&self) -> Result<BorrowedMessage<'_>, KafkaError>
Receives the next message from the stream.
This method will block until the next message is available or an error
occurs. It is legal to call recv from multiple threads simultaneously.
Note that this method is exactly as efficient as constructing a single-use message stream and extracting one message from it:
use futures::stream::StreamExt;
consumer.stream().next().await.expect("MessageStream never returns None");Sourcepub fn split_partition_queue(
self: &Arc<StreamConsumer<C, R>>,
topic: &str,
partition: i32,
) -> Option<StreamPartitionQueue<C, R>>
pub fn split_partition_queue( self: &Arc<StreamConsumer<C, R>>, topic: &str, partition: i32, ) -> Option<StreamPartitionQueue<C, R>>
Splits messages for the specified partition into their own stream.
If the topic or partition is invalid, returns None.
After calling this method, newly-fetched messages for the specified
partition will be returned via StreamPartitionQueue::recv rather
than StreamConsumer::recv. Note that there may be buffered messages
for the specified partition that will continue to be returned by
StreamConsumer::recv. For best results, call split_partition_queue
before the first call to
StreamConsumer::recv.
You must periodically await StreamConsumer::recv, even if no messages
are expected, to serve callbacks. Consider using a background task like:
tokio::spawn(async move {
let message = stream_consumer.recv().await;
panic!("main stream consumer queue unexpectedly received message: {:?}", message);
})Note that calling Consumer::assign will deactivate any existing
partition queues. You will need to call this method for every partition
that should be split after every call to assign.
Beware that this method is implemented for &Arc<Self>, not &self.
You will need to wrap your consumer in an Arc in order to call this
method. This design permits moving the partition queue to another thread
while ensuring the partition queue does not outlive the consumer.